Extension API — skills (RFC-009 Final).
ExtensionApi is the unified facade for the skill system.
The legacy ProgramManager and HostToolValidator have been removed.
Structs
- Extension
Api - Extension system calls.
Extension API — skills (RFC-009 Final).
ExtensionApi is the unified facade for the skill system.
The legacy ProgramManager and HostToolValidator have been removed.