chunk_fixed

Function chunk_fixed 

pub fn chunk_fixed(text: &str, config: &ChunkConfig) -> Vec<TextChunk>
Split text into fixed-size overlapping chunks.

Chunks are created by sliding a window of max_chunk_size characters with overlap characters of overlap between consecutive chunks.