pub fn chunk_paragraphs(text: &str, config: &ChunkConfig) -> Vec<TextChunk>Expand description
Split text into paragraphs, then group paragraphs into chunks
that don’t exceed max_chunk_size.
pub fn chunk_paragraphs(text: &str, config: &ChunkConfig) -> Vec<TextChunk>Split text into paragraphs, then group paragraphs into chunks
that don’t exceed max_chunk_size.