detect_space

Function detect_space 

pub fn detect_space<'a>(
    message: &str,
    spaces: &'a [Space],
    matcher: &PathMatcher,
) -> Option<&'a Space>
Match a message against all Spaces using a PathMatcher.

This is a convenience wrapper combining path detection with keyword matching.