pub struct TaskStore { /* private fields */ }Expand description
SQLite-backed task store.
Implementations
Sourceimpl TaskStore
impl TaskStore
Sourcepub fn new(conn: Connection) -> Result<Self>
pub fn new(conn: Connection) -> Result<Self>
Create a TaskStore from a raw connection. Schema is initialized
on the connection before it is wrapped in the async mutex, so
this constructor is safe to call from inside a Tokio runtime —
no blocking_lock is involved.
pub async fn create_task(&self, params: CreateTaskParams) -> Result<Task>
pub async fn get_task_by_id(&self, id: &str) -> Result<Task>
pub async fn list_tasks( &self, list_params: ListTasksParams, ) -> Result<Vec<Task>>
pub async fn delete_task(&self, id: &str) -> Result<()>
pub async fn update_status(&self, id: &str, status: &TaskStatus) -> Result<()>
pub async fn list_due_tasks(&self) -> Result<Vec<Task>>
pub async fn set_next_run(&self, id: &str, next_run: Option<&str>) -> Result<()>