A2A tools — let agents communicate with other agents at runtime.
Provides three tools:
a2a_delegate— delegate a task to another agent by capabilitya2a_send— send a message to a specific agenta2a_query— discover agents by capability or skill
Structs
- A2aDelegate
Tool - Tool for delegating a task to another agent discovered by capability.
- A2aQuery
Tool - Tool for discovering other agents by capability.
- A2aSend
Tool - Tool for sending a direct message to a specific agent.