pub struct BrowserTool { /* private fields */ }Expand description
Agent tool for web browsing via the embedded OxiBrowser engine.
Owns a Browser instance and lazily creates a Tab for interactive use.
Implementations
Sourceimpl BrowserTool
impl BrowserTool
Sourcepub fn new(browser: Arc<Browser>) -> Self
pub fn new(browser: Arc<Browser>) -> Self
Create a new browser tool with an already-initialized browser.
Sourcepub fn from_kernel(kernel: &KernelHandle) -> Self
pub fn from_kernel(kernel: &KernelHandle) -> Self
Create a BrowserTool from a [KernelHandle].