Memory tools for cross-session agent memory.
Provides three tools:
memory_writeโ write a memory entrymemory_readโ read/list memory entriesmemory_searchโ search memory entries by content or tags
Structs
- Memory
Read Tool - Tool for reading memory entries.
- Memory
Search Tool - Tool for searching memory entries by content or tags.
- Memory
Write Tool - Tool for writing memory entries that persist across sessions.