Module tool_types

Module tool_types 

Generic tool definition types.

ToolDef and ArgumentDef are shared across MCP adapters and other tool-bridging code. They originally lived in the program module but were extracted here as part of the RFC-009 Skill unification.

Structs

ArgumentDef
Argument definition for a tool.
ToolDef
Definition of a tool exposed by an external source (MCP server, etc.).