Module workers

Module workers 

Background worker management for the Learning layer.

Manages 12 background workers that perform periodic optimization, analysis, and learning tasks. Each worker has a type, priority, interval, and a dispatch function.

Structs

WorkerConfig
Configuration for a single worker.
WorkerManager
Manages background workers for the Learning layer.
WorkerManagerStatus
Status summary of the worker manager.
WorkerResult
Result of a worker execution.

Enums

WorkerPriority
Worker priority level.
WorkerType
All available worker types.

Traits

Worker
Trait for implementing a worker’s execution logic.