A2A (Agent-to-Agent) protocol for horizontal agent communication.
A2A is Google’s protocol for horizontal agent↔agent communication. Unlike MCP which is vertical (agent→tool), A2A enables agents to discover each other, delegate tasks, and share results.
Structs
- A2AProtocol
- A2A Protocol handler for inter-agent communication.
- A2ARequest
- A request sent by one agent to another via A2A.
- A2AResponse
- A response from a target agent.
- Agent
Card - A card describing an agent’s capabilities for discovery.
- Agent
Card Registry - Global registry of available agents and their capability cards.
- Pending
Message - A pending message waiting for an agent to receive it.
- Task
Spec - Specification for a delegated task.
Enums
- A2AMessage
- A2A Message types for inter-agent communication.
- Task
Priority - Priority level for delegated tasks.
Type Aliases
- Delegation
Handler - Callback type invoked when a TaskDelegation message is received.