pub struct Rights(pub u8);Expand description
Bit-flag rights encoded in a capability.
Rights are represented as a u8 bitmask. Standard combinations are
provided as associated constants.
| Flag | Value |
|---|---|
| NONE | 0x00 |
| READ | 0x01 |
| WRITE | 0x02 |
| EXECUTE | 0x04 |
| DELEGATE | 0x08 |
| ALL | 0x0F |
Tuple Fields
0: u8Implementations
Sourceimpl Rights
impl Rights
Sourcepub fn contains(self, other: Rights) -> bool
pub fn contains(self, other: Rights) -> bool
Returns true if this set contains all the given rights.
Sourcepub fn union(self, other: Rights) -> Rights
pub fn union(self, other: Rights) -> Rights
Returns a new Rights set with the given flags added.