Module error

Module error 

Typed error types for the Oxios kernel public API.

Library consumers should match on these variants for structured error handling. Internal implementation uses anyhow and wraps into KernelError::Internal.

Enums

HttpStatus
HTTP status code mapping (independent of any web framework).
KernelError
Oxios kernel error type.

Type Aliases

KernelResult
Convenience alias for results using KernelError.