Module browser_api

Module browser_api 

Browser API — browser backend facade.

When the browser feature is enabled, lazily initializes an Arc<oxibrowser_core::Browser> on first use from an async context. This avoids the block_on panic that occurs when constructing inside an existing tokio runtime.

Structs

BrowserApi
Browser management system calls.