Browser API — browser backend facade.
When the browser feature is enabled, holds an Arc<oxibrowser_core::Browser>
that can be shared with BrowserTool instances.
Structs
- Browser
Api - Browser management system calls.
Browser API — browser backend facade.
When the browser feature is enabled, holds an Arc<oxibrowser_core::Browser>
that can be shared with BrowserTool instances.