pub struct AutoMemoryBridge { /* private fields */ }Expand description
Bridge between Oxios memory and external memory systems.
Reads/writes MEMORY.md-style files and synchronizes with Oxios’s structured MemoryManager.
Implementations
Sourceimpl AutoMemoryBridge
impl AutoMemoryBridge
Sourcepub fn new(auto_memory_dir: PathBuf, oxios_memory: Arc<MemoryManager>) -> Self
pub fn new(auto_memory_dir: PathBuf, oxios_memory: Arc<MemoryManager>) -> Self
Create a new bridge.
Arguments
auto_memory_dir- Path to directory containing MEMORY.md filesoxios_memory- Oxios MemoryManager instance
Sourcepub async fn import_from_auto(&self) -> Result<ImportResult>
pub async fn import_from_auto(&self) -> Result<ImportResult>
Import memories from external format into Oxios.
Reads MEMORY.md files from the auto_memory_dir, parses them into structured insights, and stores them via MemoryManager.
Sourcepub async fn export_to_auto(
&self,
patterns: &[GuidancePattern],
) -> Result<ExportResult>
pub async fn export_to_auto( &self, patterns: &[GuidancePattern], ) -> Result<ExportResult>
Export Oxios patterns to external MEMORY.md format.
Reads patterns from Oxios memory and writes them as structured markdown files in the auto_memory_dir.
Sourcepub async fn sync_session(&self, direction: SyncDirection) -> Result<SyncResult>
pub async fn sync_session(&self, direction: SyncDirection) -> Result<SyncResult>
Perform a bidirectional sync.
Sourcepub fn auto_memory_dir(&self) -> &Path
pub fn auto_memory_dir(&self) -> &Path
Returns the auto-memory directory path.