pub trait Supervisor: Send + Sync {
// Required methods
fn fork<'life0, 'life1, 'async_trait>(
&'life0 self,
spec: &'life1 Seed,
) -> Pin<Box<dyn Future<Output = Result<AgentId>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn exec<'life0, 'async_trait>(
&'life0 self,
id: AgentId,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn run_with_seed<'life0, 'life1, 'async_trait>(
&'life0 self,
id: AgentId,
seed: &'life1 Seed,
) -> Pin<Box<dyn Future<Output = Result<ExecutionResult>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn wait<'life0, 'async_trait>(
&'life0 self,
id: AgentId,
) -> Pin<Box<dyn Future<Output = Result<AgentStatus>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn kill<'life0, 'async_trait>(
&'life0 self,
id: AgentId,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn list<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<AgentInfo>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Supervisor trait for managing agent lifecycles.
Required Methods
Sourcefn fork<'life0, 'life1, 'async_trait>(
&'life0 self,
spec: &'life1 Seed,
) -> Pin<Box<dyn Future<Output = Result<AgentId>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn fork<'life0, 'life1, 'async_trait>(
&'life0 self,
spec: &'life1 Seed,
) -> Pin<Box<dyn Future<Output = Result<AgentId>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Fork a new agent from a seed specification.
Sourcefn exec<'life0, 'async_trait>(
&'life0 self,
id: AgentId,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn exec<'life0, 'async_trait>(
&'life0 self,
id: AgentId,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Start executing an agent.
Sourcefn run_with_seed<'life0, 'life1, 'async_trait>(
&'life0 self,
id: AgentId,
seed: &'life1 Seed,
) -> Pin<Box<dyn Future<Output = Result<ExecutionResult>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn run_with_seed<'life0, 'life1, 'async_trait>(
&'life0 self,
id: AgentId,
seed: &'life1 Seed,
) -> Pin<Box<dyn Future<Output = Result<ExecutionResult>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Fork and execute an agent with its seed, running to completion. Returns the execution result from the agent runtime.
Sourcefn wait<'life0, 'async_trait>(
&'life0 self,
id: AgentId,
) -> Pin<Box<dyn Future<Output = Result<AgentStatus>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn wait<'life0, 'async_trait>(
&'life0 self,
id: AgentId,
) -> Pin<Box<dyn Future<Output = Result<AgentStatus>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Wait for an agent to complete and return its final status.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".