Module a2a_tools

Module a2a_tools 

A2A tools — let agents communicate with other agents at runtime.

Provides three tools:

  • a2a_delegate — delegate a task to another agent by capability
  • a2a_send — send a message to a specific agent
  • a2a_query — discover agents by capability or skill

Structs

A2aDelegateTool
Tool for delegating a task to another agent discovered by capability.
A2aQueryTool
Tool for discovering other agents by capability.
A2aSendTool
Tool for sending a direct message to a specific agent.